summaryrefslogtreecommitdiffstats
path: root/markup/converter/hooks/hooks.go
diff options
context:
space:
mode:
Diffstat (limited to 'markup/converter/hooks/hooks.go')
-rw-r--r--markup/converter/hooks/hooks.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/markup/converter/hooks/hooks.go b/markup/converter/hooks/hooks.go
index a570113ff..e81689f04 100644
--- a/markup/converter/hooks/hooks.go
+++ b/markup/converter/hooks/hooks.go
@@ -90,11 +90,11 @@ type HeadingRenderer interface {
identity.Provider
}
// ElementPositionRevolver provides a way to resolve the start Position
// of a markdown element in the original source document.
// This may be both slow and aproximate, so should only be
// used for error logging.
-type ElementPositionRevolver interface {
+type ElementPositionResolver interface {
ResolvePosition(ctx interface{}) text.Position
}
@@ -90,11 +90,11 @@ type HeadingRenderer interface {
identity.Provider
}
-// ElementPositionRevolver provides a way to resolve the start Position
+// ElementPositionResolver provides a way to resolve the start Position
// of a markdown element in the original source document.
// This may be both slow and aproximate, so should only be